@@ -2,15 +2,18 @@ from . import base
 from . import antique
 from . import aquaint
 from . import car
+from . import clinicaltrials
 from . import clueweb09
 from . import clueweb12
 from . import cord19
 from . import codesearchnet
+from . import gov
 from . import gov2
 from . import highwire
 from . import medline
 from . import msmarco_passage
 from . import msmarco_document
+from . import msmarco_qna
 from . import nfcorpus
 from . import trec_robust04
 from . import nyt
@@ -18,4 +21,6 @@ from . import pmc
 from . import trec_arabic
 from . import trec_mandarin
 from . import trec_spanish
+from . import tweets2013_ia
 from . import vaswani
+from . import wikir
