@@ -1,4 +1,5 @@
 import contextlib
+from typing import Tuple
 import io
 import ir_datasets
 from .base import GenericDoc, GenericQuery, GenericDocPair, BaseDocs, BaseQueries, BaseDocPairs
@@ -78,8 +79,19 @@ class TsvIter:
     def __next__(self):
         line = next(self.line_iter)
         cols = line.rstrip('\n').split('\t')
-        if len(cols) != len(self.cls._fields):
-            raise RuntimeError(f'expected {len(self.cls._fields)} fields, got {len(cols)}')
+        num_cols = len(self.cls._fields)
+        last_field = self.cls.__annotations__[self.cls._fields[-1]] if hasattr(self.cls, '__annotations__') else None
+        if last_field == Tuple[str, ...]:
+            if len(cols) < len(self.cls._fields) - 1:
+                raise RuntimeError(f'expected at least {len(self.cls._fields)-1} fields, got {len(cols)}')
+            if len(cols) == len(self.cls._fields) - 1:
+                cols += ((),)
+            else:
+                cols[len(self.cls._fields)-1] = tuple(cols[len(self.cls._fields)-1:])
+                cols = cols[:len(self.cls._fields)]
+        else:
+            if len(cols) != len(self.cls._fields):
+                raise RuntimeError(f'expected {len(self.cls._fields)} fields, got {len(cols)}')
         return self.cls(*cols)
 
     def __getitem__(self, key):
@@ -104,10 +116,11 @@ class _TsvBase:
 
 
 class TsvDocs(_TsvBase, BaseDocs):
-    def __init__(self, docs_dlc, doc_cls=GenericDoc, doc_store_index_fields=None, namespace=None):
+    def __init__(self, docs_dlc, doc_cls=GenericDoc, doc_store_index_fields=None, namespace=None, lang=None):
         super().__init__(docs_dlc, doc_cls, "docs")
         self._doc_store_index_fields = doc_store_index_fields
         self._docs_namespace = namespace
+        self._docs_lang = lang
 
     def docs_path(self):
         return self._path()
@@ -137,11 +150,15 @@ class TsvDocs(_TsvBase, BaseDocs):
             return self.docs_store().count()
         return None
 
+    def docs_lang(self):
+        return self._docs_lang
+
 
 class TsvQueries(_TsvBase, BaseQueries):
-    def __init__(self, queries_dlc, query_cls=GenericQuery, namespace=None):
+    def __init__(self, queries_dlc, query_cls=GenericQuery, namespace=None, lang=None):
         super().__init__(queries_dlc, query_cls, "queries")
         self._queries_namespace = namespace
+        self._queries_lang = lang
 
     def queries_path(self):
         return self._path()
@@ -155,6 +172,9 @@ class TsvQueries(_TsvBase, BaseQueries):
     def queries_namespace(self):
         return self._queries_namespace
 
+    def queries_lang(self):
+        return self._queries_lang
+
 
 class TsvDocPairs(_TsvBase, BaseDocPairs):
     def __init__(self, docpairs_dlc, docpair_cls=GenericDocPair):
